==> haskell-lucid-2.11.20230408-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lucid
version:              2.11.20230408
visibility:           public
id:                   lucid-2.11.20230408-66ROsipHcNfKexFxphBHut
key:                  lucid-2.11.20230408-66ROsipHcNfKexFxphBHut
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  de51c203424cf0241011d47af375be50
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20230408
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20230408
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20230408
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20230408-66ROsipHcNfKexFxphBHut
depends:
    base-4.17.2.1 blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28 mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.11.20230408-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lucid
version:              2.11.20230408
visibility:           public
id:                   lucid-2.11.20230408-6FtA5Vj2F6V3z0zPjuLrOo
key:                  lucid-2.11.20230408-6FtA5Vj2F6V3z0zPjuLrOo
license:              BSD-3-Clause
copyright:            2014-2021 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
homepage:             https://github.com/chrisdone/lucid
synopsis:             Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.

    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)

    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')

    * For more, read <https://chrisdone.com/posts/lucid the blog post>

    See the "Lucid" module for more documentation.

category:             Web
abi:                  8962ab9a30689db66ff1b02b273af031
exposed:              True
exposed-modules:      Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20230408
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20230408
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lucid-2.11.20230408
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lucid
hs-libraries:         HSlucid-2.11.20230408-6FtA5Vj2F6V3z0zPjuLrOo
depends:
    base-4.17.2.1 blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-5O85VrI4oZ4EDBPYdTgwgk
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28 mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html:         /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
